==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/crm/ElemeBenefitDTO.java <==
package eleme.openapi.sdk.api.entity.crm;

import eleme.openapi.sdk.api.entity.crm.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class ElemeBenefitDTO{

    /**
     * 饿了么门店入淘id
     */
    private String eleStoreId;
    public String getEleStoreId() {
        return eleStoreId;
    }
    public void setEleStoreId(String eleStoreId) {
        this.eleStoreId = eleStoreId;
    }
    
    /**
     * 饿了么门店id
     */
    private String eleShopId;
    public String getEleShopId() {
        return eleShopId;
    }
    public void setEleShopId(String eleShopId) {
        this.eleShopId = eleShopId;
    }
    
    /**
     * crm品牌id
     */
    private String brandId;
    public String getBrandId() {
        return brandId;
    }
    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }
    
    /**
     * l100SellerId
     */
    private String brandSellerId;
    public String getBrandSellerId() {
        return brandSellerId;
    }
    public void setBrandSellerId(String brandSellerId) {
        this.brandSellerId = brandSellerId;
    }
    
    /**
     * 品牌logo
     */
    private String brandLogo;
    public String getBrandLogo() {
        return brandLogo;
    }
    public void setBrandLogo(String brandLogo) {
        this.brandLogo = brandLogo;
    }
    
    /**
     * 品牌名称
     */
    private String brandName;
    public String getBrandName() {
        return brandName;
    }
    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    
    /**
     * 招商活动id
     */
    private String recruitId;
    public String getRecruitId() {
        return recruitId;
    }
    public void setRecruitId(String recruitId) {
        this.recruitId = recruitId;
    }
    
    /**
     * activityId
     */
    private String activityId;
    public String getActivityId() {
        return activityId;
    }
    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }
    
    /**
     * 抽发奖活动id
     */
    private String drawActivityId;
    public String getDrawActivityId() {
        return drawActivityId;
    }
    public void setDrawActivityId(String drawActivityId) {
        this.drawActivityId = drawActivityId;
    }
    
    /**
     * 券模版id
     */
    private String voucherTemplateId;
    public String getVoucherTemplateId() {
        return voucherTemplateId;
    }
    public void setVoucherTemplateId(String voucherTemplateId) {
        this.voucherTemplateId = voucherTemplateId;
    }
    
    /**
     * 权益子类型
     */
    private String benefitSubType;
    public String getBenefitSubType() {
        return benefitSubType;
    }
    public void setBenefitSubType(String benefitSubType) {
        this.benefitSubType = benefitSubType;
    }
    
    /**
     * 权益优惠类型
     */
    private String benefitDiscountType;
    public String getBenefitDiscountType() {
        return benefitDiscountType;
    }
    public void setBenefitDiscountType(String benefitDiscountType) {
        this.benefitDiscountType = benefitDiscountType;
    }
    
    /**
     * 权益名称
     */
    private String benefitName;
    public String getBenefitName() {
        return benefitName;
    }
    public void setBenefitName(String benefitName) {
        this.benefitName = benefitName;
    }
    
    /**
     * 权益图片
     */
    private String benefitImgUrl;
    public String getBenefitImgUrl() {
        return benefitImgUrl;
    }
    public void setBenefitImgUrl(String benefitImgUrl) {
        this.benefitImgUrl = benefitImgUrl;
    }
    
    /**
     * 权益值(劵折扣,劵面额,菜品特价值)
     */
    private String benefitValue;
    public String getBenefitValue() {
        return benefitValue;
    }
    public void setBenefitValue(String benefitValue) {
        this.benefitValue = benefitValue;
    }
    
    /**
     * 权益门槛(劵门槛,商品原价)
     */
    private String benefitThreshold;
    public String getBenefitThreshold() {
        return benefitThreshold;
    }
    public void setBenefitThreshold(String benefitThreshold) {
        this.benefitThreshold = benefitThreshold;
    }
    
    /**
     * 权益可用时段
     */
    private String availableTimeDesc;
    public String getAvailableTimeDesc() {
        return availableTimeDesc;
    }
    public void setAvailableTimeDesc(String availableTimeDesc) {
        this.availableTimeDesc = availableTimeDesc;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/crm/ElemeBenefitDTO.java <==
package eleme.openapi.sdk.api.entity.crm;

import eleme.openapi.sdk.api.enumeration.crm.*;
import eleme.openapi.sdk.api.entity.crm.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class ElemeBenefitDTO{

    /**
     * 饿了么门店入淘id
     */
    private String eleStoreId;
    public String getEleStoreId() {
        return eleStoreId;
    }
    public void setEleStoreId(String eleStoreId) {
        this.eleStoreId = eleStoreId;
    }
    
    /**
     * 饿了么门店id
     */
    private String eleShopId;
    public String getEleShopId() {
        return eleShopId;
    }
    public void setEleShopId(String eleShopId) {
        this.eleShopId = eleShopId;
    }
    
    /**
     * crm品牌id
     */
    private String brandId;
    public String getBrandId() {
        return brandId;
    }
    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }
    
    /**
     * l100SellerId
     */
    private String brandSellerId;
    public String getBrandSellerId() {
        return brandSellerId;
    }
    public void setBrandSellerId(String brandSellerId) {
        this.brandSellerId = brandSellerId;
    }
    
    /**
     * 品牌logo
     */
    private String brandLogo;
    public String getBrandLogo() {
        return brandLogo;
    }
    public void setBrandLogo(String brandLogo) {
        this.brandLogo = brandLogo;
    }
    
    /**
     * 品牌名称
     */
    private String brandName;
    public String getBrandName() {
        return brandName;
    }
    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    
    /**
     * 招商活动id
     */
    private String recruitId;
    public String getRecruitId() {
        return recruitId;
    }
    public void setRecruitId(String recruitId) {
        this.recruitId = recruitId;
    }
    
    /**
     * activityId
     */
    private String activityId;
    public String getActivityId() {
        return activityId;
    }
    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }
    
    /**
     * 抽发奖活动id
     */
    private String drawActivityId;
    public String getDrawActivityId() {
        return drawActivityId;
    }
    public void setDrawActivityId(String drawActivityId) {
        this.drawActivityId = drawActivityId;
    }
    
    /**
     * 券模版id
     */
    private String voucherTemplateId;
    public String getVoucherTemplateId() {
        return voucherTemplateId;
    }
    public void setVoucherTemplateId(String voucherTemplateId) {
        this.voucherTemplateId = voucherTemplateId;
    }
    
    /**
     * 权益子类型
     */
    private String benefitSubType;
    public String getBenefitSubType() {
        return benefitSubType;
    }
    public void setBenefitSubType(String benefitSubType) {
        this.benefitSubType = benefitSubType;
    }
    
    /**
     * 权益优惠类型
     */
    private String benefitDiscountType;
    public String getBenefitDiscountType() {
        return benefitDiscountType;
    }
    public void setBenefitDiscountType(String benefitDiscountType) {
        this.benefitDiscountType = benefitDiscountType;
    }
    
    /**
     * 权益名称
     */
    private String benefitName;
    public String getBenefitName() {
        return benefitName;
    }
    public void setBenefitName(String benefitName) {
        this.benefitName = benefitName;
    }
    
    /**
     * 权益图片
     */
    private String benefitImgUrl;
    public String getBenefitImgUrl() {
        return benefitImgUrl;
    }
    public void setBenefitImgUrl(String benefitImgUrl) {
        this.benefitImgUrl = benefitImgUrl;
    }
    
    /**
     * 权益值(劵折扣,劵面额,菜品特价值)
     */
    private String benefitValue;
    public String getBenefitValue() {
        return benefitValue;
    }
    public void setBenefitValue(String benefitValue) {
        this.benefitValue = benefitValue;
    }
    
    /**
     * 权益门槛(劵门槛,商品原价)
     */
    private String benefitThreshold;
    public String getBenefitThreshold() {
        return benefitThreshold;
    }
    public void setBenefitThreshold(String benefitThreshold) {
        this.benefitThreshold = benefitThreshold;
    }
    
    /**
     * 权益可用时段
     */
    private String availableTimeDesc;
    public String getAvailableTimeDesc() {
        return availableTimeDesc;
    }
    public void setAvailableTimeDesc(String availableTimeDesc) {
        this.availableTimeDesc = availableTimeDesc;
    }
    
    /**
     * 权益优惠金额单位分排序用
     */
    private Long benefitValueAmt;
    public Long getBenefitValueAmt() {
        return benefitValueAmt;
    }
    public void setBenefitValueAmt(Long benefitValueAmt) {
        this.benefitValueAmt = benefitValueAmt;
    }
    
    /**
     * 权益门槛单位分排序用
     */
    private Long benefitThresholdAmt;
    public Long getBenefitThresholdAmt() {
        return benefitThresholdAmt;
    }
    public void setBenefitThresholdAmt(Long benefitThresholdAmt) {
        this.benefitThresholdAmt = benefitThresholdAmt;
    }
    
}
